@@ -7,6 +7,6 @@ function(x) {
     for (i in 1:length(lengths)) {
         strings <- c(strings, sort(x[which(nchar(x) == lengths[i])]))
         }
-    strings
+    return(strings)
     }
 
